@@ -1,177 +1,144 @@
 # emulate default behaviors for the various signals.
 
 package Signals::XSIG::Default;
-
-## no critic (RequireLocalizedPunctuationVars)
-
 use strict;
 use warnings;
 use Config;
 use Carp;
 use POSIX ();
-use Exporter;
-
-our @ISA = qw(Exporter);
-our @EXPORT = qw(%DEFAULT_BEHAVIOR);
 
 our %DEFAULT_BEHAVIOR;
-our $VERSION = '0.15_04';
+our $VERSION = $Signals::XSIG::VERSION;
 
 my @snam = split ' ', $Config{sig_name};
 my @snum = split ' ', $Config{sig_num};
 
 sub import {
-    my $ignore = 1;
-    while (<DATA>) {
-	next if /^#/;
-	next unless /\S/;
-	if (/^\[(.+)\]/) {
-	    if ($1 eq 'default' || $1 eq $^O) {
-		$ignore = 0;
-	    } else {
-		$ignore = 1;
-	    }
-	} elsif (/\{(.+)\/(\d+)\}/) {
-	    if ($1 eq $^O && $2 <= int($] * 1000)) {
-		$ignore = 0;
-	    } else {
-		$ignore = 1;
-	    }
-	} elsif (!$ignore) {
-	    s/^\d+\. //;
-	    s/^SIG//;
-	    my ($sig, $num, $behavior) = /^(\w+)\s+\[(\d*)\]\s+=>\s+(.+)/;
-	    if (defined $sig) {
-		$DEFAULT_BEHAVIOR{$sig} = $behavior;
-	    }
-	}
+  my $ignore = 1;
+  while (<DATA>) {
+    next unless /\S/;
+    if (/^\[(.+)\]/) {
+      if ($1 eq 'default' || $1 eq $^O) {
+	$ignore = 0;
+      } else {
+	$ignore = 1;
+      }
+    } elsif (/\{(.+)\/(\d+)\}/) {
+      if ($1 eq $^O && $2 <= int($] * 1000)) {
+	$ignore = 0;
+      } else {
+	$ignore = 1;
+      }
+    } elsif (!$ignore) {
+      s/^\d+\. //;
+      s/^SIG//;
+      my ($sig, $num, $behavior) = /^(\w+)\s+\[(\d*)\]\s+=>\s+(.+)/;
+      $DEFAULT_BEHAVIOR{$sig} = $behavior;
     }
-    return;
+  }
 }
 
 sub perform_default_behavior {
-    my ($signal, @args) = @_;
+  my $signal = shift;
+  my $funcname = 'default_SIG' . $signal;
+  if (defined &$funcname) {
+    no strict 'refs';
+    return if $funcname->($signal, @_);
+  }
 
-    my $funcname = 'default_SIG' . $signal;
-    if (defined &$funcname) {
-	no strict 'refs';                    ## no critic (NoStrict)
-	return if $funcname->($signal, @args);
+  my $behavior = $DEFAULT_BEHAVIOR{$signal};
+  if (!defined $behavior) {
+    if ($signal =~ /^NUM(\d+)/) {
+      my $signum = 0 + $1;
+      $behavior = $DEFAULT_BEHAVIOR{"NUMxx"};
+      $behavior =~ s/xx/$signum/;
     }
-
-    my $behavior = $DEFAULT_BEHAVIOR{$signal};
     if (!defined $behavior) {
-	if ($signal =~ /^NUM(\d+)/) {
-	    my $signum = 0 + $1;
-	    $behavior = $DEFAULT_BEHAVIOR{"NUMxx"};
-	    $behavior =~ s/xx/$signum/;
-	}
-	if (!defined $behavior) {
-	    croak "Signals::XSIG: no default behavior is specified ",
-	        "for SIG$signal. Terminating this program.\n";
-	}
+      croak "Signals::XSIG: no default behavior is specified ",
+	"for SIG$signal. Terminating this program.\n";
+    }
+  }
+
+  if ($behavior eq 'IGNORE') {
+    return;
+  }
+
+  if ($behavior eq 'SUSPEND') {
+    suspend($signal);
+    # ... then wait for the SIGCONT ... 
+    return;
+  }
+
+  if ($behavior =~ /^ABORT/) {
+    untie %SIG;
+    %SIG = ();
+    $SIG{$signal} = $SIG{"ABRT"} = "DEFAULT";
+    killprog_with_signal("ABRT");
+    POSIX::abort();
+    croak "Abort\n";
+  }
+  if ($behavior =~ /^SIGSEGV/) {
+    killprog_with_signal('SEGV');
+    croak "Abort\n";
+  }
+
+  if ($behavior =~ /^EXIT (\d+)/) {
+    my $exit_code = $1;
+    exit($exit_code);
+  }
+
+  if ($behavior =~ /^TERMINATE/) {
+    my $no;
+    for (my $i=0; $i<@snum; $i++) {
+      $no = $snum[$i] if $signal eq $snam[$i];
     }
 
-    if (ref($behavior) eq 'CODE') {
-	if (defined &$behavior) {
-	    $behavior->($signal);
-	    return;
-	} else {
-	    carp "Signals::XSIG: Default behavior for SIG$signal ",
-	        "is not set to a valid subroutine.";
-	    return;
-	}
-    }
+    killprog_with_signal($signal, $no);
+    croak "default behavior for SIG$signal should have killed script ",
+        "but for some reason it didn't  :-(\n";
+  }
 
-    if ($behavior eq 'IGNORE') {
-	return;
-    }
-
-    if ($behavior eq 'SUSPEND') {
-	suspend($signal);
-	# ... then wait for the SIGCONT ... 
-	return;
-    }
-
-    if ($behavior =~ /^ABORT/) {
-	untie %SIG;
-	%SIG = ();
-	$SIG{$signal} = $SIG{"ABRT"} = "DEFAULT";
-	killprog_with_signal("ABRT");
-	POSIX::abort();
-	croak "Abort\n";
-    }
-    if ($behavior =~ /^SIGSEGV/) {
-	killprog_with_signal('SEGV');
-	croak "Abort\n";
-    }
-
-    if ($behavior =~ /^EXIT (\d+)/) {
-	my $exit_code = $1;
-	exit($exit_code);
-    }
-
-    if ($behavior =~ /^TERMINATE/) {
-	my $number;
-	for (my $i=0; $i<@snum; $i++) {
-	    $number = $snum[$i] if $signal eq $snam[$i];
-	}
-
-	killprog_with_signal($signal, $number);
-	croak "default behavior for SIG$signal should have killed script ",
-            "but for some reason it didn't  :-(\n";
-    }
-
-    croak "Signals::XSIG: unknown behavior \"$behavior\" ",
-        "for SIG$signal. Terminating this program.\n";
+  croak "Signals::XSIG: unknown behavior \"$behavior\" ",
+    "for SIG$signal. Terminating this program.\n";
 }
 
 sub killprog_with_signal {
-    my ($sig,$sig_no) = @_;
-    untie %SIG;
-    %SIG = ();
-    $SIG{$sig} = 'DEFAULT';
+  my ($sig,$sig_no) = @_;
+  untie %SIG;
+  %SIG = ();
+  $SIG{$sig} = 'DEFAULT';
 
-    unless ($sig_no) {
-	my @sig_name = split ' ', $Config{sig_name};
-	($sig_no) = grep { $sig eq $sig_name[$_] } split ' ',$Config{sig_num};
+  unless ($sig_no) {
+    my @sig_name = split ' ', $Config{sig_name};
+    my ($sig_no) = grep { $sig eq $sig_name[$_] } split ' ',$Config{sig_num};
+  }
+
+  kill $sig, $$;
+  eval {
+    use POSIX ();
+    if ($sig_no) {
+      # this is needed for Linux
+      POSIX::sigaction($sig_no, &POSIX::SIG_DFL);
+      POSIX::sigprocmask(&POSIX::SIG_UNBLOCK, POSIX::SigSet->new($sig_no));
     }
+  };
+  kill $sig, $$;
 
-    kill $sig, $$;
-    sleep 1 if $^O eq 'MSWin32';
-    eval {
-	use POSIX ();
-	if ($sig_no) {
-	    # this is needed for Linux
-	    POSIX::sigaction($sig_no, &POSIX::SIG_DFL);
-	    POSIX::sigprocmask(&POSIX::SIG_UNBLOCK, 
-			       POSIX::SigSet->new($sig_no));
-	}
-    } or ();
-    kill $sig, $$;
-    sleep 1 if $^O eq 'MSWin32';
-
-    my $miniprog = q[$SIG{'__SIGNAL__'}='DEFAULT';
-                     kill '__SIGNAL__',$$;sleep 1+"MSWin32"eq$^O;die];
-    $miniprog =~ s/__SIGNAL__/$sig/g;
-    exec($^X, "-e", $miniprog);
+  my $miniprog = q[$SIG{'__SIGNAL__'}='DEFAULT';
+                   kill '__SIGNAL__',$$;sleep 1;die];
+  $miniprog =~ s/__SIGNAL__/$sig/g;
+  exec($^X, "-e", $miniprog);
 }
 
 # in principle, SIGSTOP cannot be trapped.
 sub suspend {
-    if ($^O eq 'MSWin32') {
-	# MSWin32 doesn't have signals as such.
-	# Win32::API->SuspendProcess / SuspendThread ?
-	# Win32::Process->suspend ?
-	# Win32::Thread->suspend ?
-	if ($$ > 0) {
-	    # suspend process
-	    #   enumerate all threads in process
-	    #   suspend each thread
-	} else {
-	    # suspend thread
-	}
-    }
-    return kill 'STOP', $$;
+  if ($^O eq 'MSWin32') {
+    # MSWin32 doesn't have signals as such.
+    # Win32::API->SuspendProcess / SuspendThread ?
+    # Win32::Process->suspend ?
+    # Win32::Thread->suspend ?
+  }
+  kill 'STOP', $$;
 }
 
 ##################################################################
@@ -183,14 +150,14 @@ sub suspend {
 # Return true if the signal is "handled" and no further 
 # processing is necessary.
 
-sub default_SIG__WARN__ {          ## no critic (Unpacking)
-    CORE::warn @_;
-    return 1;
+sub default_SIG__WARN__ {
+  CORE::warn @_;
+  return 1;
 }
 
-sub default_SIG__DIE__ {          ## no critic (Unpacking)
-    CORE::die @_;
-    return 1;
+sub default_SIG__DIE__ {
+  CORE::die @_;
+  return 1;
 }
 
 1;
@@ -201,11 +168,10 @@ Signals::XSIG::Default
 
 =head1 DESCRIPTION
 
-Module for emulating the default behavior for all
+Module to emulate the default signal handler behavior for all
 signals in your system. The emulator is used when you have
 used L<Signals::XSIG> to register more than one 
-handler for a signal, and at least one of those 
-handlers is C<DEFAULT>.
+handler for a signal, and one of those handlers is C<DEFAULT>.
 
 See L<Signals::XSIG> for much more information.
 
@@ -219,9 +185,6 @@ See L<Signals::XSIG> for much more information.
 #    spike/analyze_default_signal_behavior.pl
 # and include that data at the end of this file ...
 #
-# we can also infer behavior from CPAN tester results,
-# see t/20-defaults.t
-#
 __DATA__
 [default]
 ABRT [] => ABORT
@@ -231,7 +194,6 @@ BUS [] => TERMINATE
 CHLD [] => IGNORE
 CLD [] => IGNORE
 CONT [] => IGNORE
-EMT [] => TERMINATE
 FPE [] => TERMINATE
 HUP [] => TERMINATE
 ILL [] => TERMINATE
@@ -331,135 +293,6 @@ ZERO    [0] => IGNORE
 __DIE__ [] => IGNORE
 __WARN__ [] => IGNORE
 
-[aix]
-AIO	[]   => IGNORE
-IOINT   []   => IGNORE
-POLL	[]   => IGNORE
-SEGV    [11] => TERMINATE 11
-URG	[]   => URG
-
-[cygwin]
-ABRT    [6] => TERMINATE 134
-ALRM    [14] => TERMINATE 14
-BUS     [10] => TERMINATE 10
-CHLD    [20] => IGNORE
-CLD     [20] => IGNORE
-CONT    [19] => IGNORE
-EMT     [7] => TERMINATE 7
-FPE     [8] => TERMINATE 8
-HUP     [1] => TERMINATE 1
-ILL     [4] => TERMINATE 4
-INT     [2] => TERMINATE 2
-IO      [23] => IGNORE
-KILL    [9] => TERMINATE 9
-LOST    [29] => TERMINATE 29
-PIPE    [13] => TERMINATE 13
-POLL    [23] => IGNORE
-PROF    [27] => TERMINATE 27
-PWR     [29] => TERMINATE 29
-QUIT    [3] => TERMINATE 131
-RTMAX   [32] => TERMINATE 32
-RTMIN   [32] => TERMINATE 32
-SEGV    [11] => TERMINATE 11
-STOP    [17] => SUSPEND
-SYS     [12] => TERMINATE 12
-TERM    [15] => TERMINATE 15
-TRAP    [5] => TERMINATE 5
-TSTP    [18] => SUSPEND
-TTIN    [21] => SUSPEND
-TTOU    [22] => SUSPEND
-URG     [16] => IGNORE
-USR1    [30] => TERMINATE 30
-USR2    [31] => TERMINATE 31
-VTALRM  [26] => TERMINATE 26
-WINCH   [28] => IGNORE
-XCPU    [24] => TERMINATE 24
-XFSZ    [25] => TERMINATE 25
-ZERO    [] => IGNORE
-__DIE__ [] => IGNORE
-__WARN__ [] => IGNORE
-
-# www.cpantesters.org/cpan/report/4d60a820-e5c2-11df-bf62-5eb33ef6c52e
-[darwin]
-ABRT   [6] => TERMINATE 6
-EMT    [7] => TERMINATE 7
-SEGV   [11] => TERMINATE 11
-IO     [] => IGNORE
-IOT    [6] => TERMINATE 6
-TSTP    [18] => IGNORE
-TTIN    [21] => IGNORE
-TTOU    [22] => IGNORE
-
-# www.cpantesters.org/cpan/report/4b99dd2a-e60f-11df-bb29-ad544afd17af
-[dragonfly]
-ABRT [6] => TERMINATE 134
-EMT [7] => TERMINATE 135
-SEGV [11] => TERMINATE 139
-IO [] => IGNORE
-IOT [] => TERMINATE 134
-
-# www.cpantesters.org/cpan/report/62d0832e-e621-11df-858d-e879df34a846a
-[freebsd]
-ABRT [6] => TERMINATE 134
-EMT [7] => TERMINATE 135
-SEGV [11] => TERMINATE 139
-IO [] => IGNORE
-IOT [] => TERMINATE 134
-TSTP [] => IGNORE
-TTIN [] => IGNORE
-TTOU [] => IGNORE
-
-[gnukfreebsd]
-ABRT [6] => TERMINATE 134
-EMT [7] => TERMINATE 135
-SEGV [11] => TERMINATE 139
-IO [23] => IGNORE
-IOT [] => TERMINATE 134
-POLL [23] => IGNORE
-TSTP [] => IGNORE
-TTIN [] => IGNORE
-TTOU [] => IGNORE
-
-# www.cpantesters.org/cpan/report/c8635a72-e5d6-11df-a833-d9c7245fd73a
-[irix]
-ABRT [6] => TERMINATE 134
-EMT [7] => TERMINATE 135
-SEGV [11] => TERMINATE 139
-RTMIN [49] => TERMINATE 49
-RTMAX [64] => TERMINATE 64
-IOT [] => TERMINATE 134
-
-# www.cpantesters.org/cpan/report/8da6fe76-26f2-11e1-953f-bc4e84dee9ce
-[mirbsd]
-ILL [4] => TERMINATE 132
-BUS [10] => TERMINATE 138
-SEGV [11] => TERMINATE 139
-
-# www.cpantesters.org/cpan/report/209fd0b6-e61e-11df-bb29-ad544afd17af
-[netbsd]
-ABRT [6] => TERMINATE 134
-EMT [7] => TERMINATE 135
-SEGV [11] => TERMINATE 139
-IO [] => IGNORE
-IOT [6] = TERMINATE 134
-TSTP [] => IGNORE
-TTIN [] => IGNORE
-TTOU [] => IGNORE
-
-[openbsd]
-ILL [4] => TERMINATE 132
-ABRT [6] => TERMINATE 134
-EMT [7] => TERMINATE 135
-BUS [10] => TERMINATE 138
-SEGV [11] => TERMINATE 139
-IO [] => IGNORE
-
-[mirbsd]
-ILL [4] => TERMINATE 132
-BUS [10] => TERMINATE 138
-SEGV [11] => TERMINATE 139
-IO [] => IGNORE
-
 [solaris]
 ABRT    [6] => TERMINATE 134
 ALRM    [14] => TERMINATE 14
@@ -510,3 +343,44 @@ XRES    [38] => IGNORE
 ZERO    [] => IGNORE
 __DIE__ [] => IGNORE
 __WARN__ [] => IGNORE
+
+[cygwin]
+ABRT    [6] => TERMINATE 134
+ALRM    [14] => TERMINATE 14
+BUS     [10] => TERMINATE 10
+CHLD    [20] => IGNORE
+CLD     [20] => IGNORE
+CONT    [19] => IGNORE
+EMT     [7] => TERMINATE 7
+FPE     [8] => TERMINATE 8
+HUP     [1] => TERMINATE 1
+ILL     [4] => TERMINATE 4
+INT     [2] => TERMINATE 2
+IO      [23] => IGNORE
+KILL    [9] => TERMINATE 9
+LOST    [29] => TERMINATE 29
+PIPE    [13] => TERMINATE 13
+POLL    [23] => IGNORE
+PROF    [27] => TERMINATE 27
+PWR     [29] => TERMINATE 29
+QUIT    [3] => TERMINATE 131
+RTMAX   [32] => TERMINATE 32
+RTMIN   [32] => TERMINATE 32
+SEGV    [11] => TERMINATE 11
+STOP    [17] => SUSPEND
+SYS     [12] => TERMINATE 12
+TERM    [15] => TERMINATE 15
+TRAP    [5] => TERMINATE 5
+TSTP    [18] => SUSPEND
+TTIN    [21] => SUSPEND
+TTOU    [22] => SUSPEND
+URG     [16] => IGNORE
+USR1    [30] => TERMINATE 30
+USR2    [31] => TERMINATE 31
+VTALRM  [26] => TERMINATE 26
+WINCH   [28] => IGNORE
+XCPU    [24] => TERMINATE 24
+XFSZ    [25] => TERMINATE 25
+ZERO    [] => IGNORE
+__DIE__ [] => IGNORE
+__WARN__ [] => IGNORE
